@@ -52,9 +52,12 @@ class Collect:
             logger.info(f"Object {key} already exists")
             return True
         for key, part, obj in self.db.get_objects(key):
-            if isinstance(obj, bytes):
-                obj = io.BytesIO(obj)
-            self.sh.save_obj(obj.read(), cdclass, key, part)
+            try:
+                if isinstance(obj, bytes):
+                    obj = io.BytesIO(obj)
+                self.sh.save_obj(obj.read(), cdclass, key, part)
+            except AttributeError:
+                logger.error(f"The key {key} has a empty file, it will be ignored")
 
     def get_keys(self, cdclass):
         exists, docs = self.sh.check_meta(f"DOCS_LIST_{cdclass}")
