@@ -19,7 +19,7 @@ class Query:
     def run(self, sql, filename):
         logger.info(f"Reading SQL file in {sql}")
 
-        with open(sql, "r") as f:
+        with open(sql, "r", encoding="utf8", errors="ignore") as f:
             query = f.read()
 
         logger.info("Running query")
